@@ -4,7 +4,8 @@
 
 from .__version__ import __version__
 
-from . import typing_utils, empty, utils, testing_utils, numpy_utils, schema, file_container
+from . import (typing_utils, empty, utils, testing_utils, numpy_utils, schema,
+               file_container, hdf5_utils, yaml_utils)
 from .typing_utils import *
 from .empty import *
 from .utils import *
@@ -15,6 +16,8 @@ from .schema import (
     Default, Formatter, supports_float, supports_int,
     isinstance_factory, issubclass_factory, import_factory
 )
+from .hdf5_utils import *
+from .yaml_utils import *
 
 __author__ = 'B. F. van Beek'
 __email__ = 'b.f.van.beek@vu.nl'
@@ -28,4 +31,6 @@ __all__ += testing_utils.__all__
 __all__ += numpy_utils.__all__
 __all__ += schema.__all__
 __all__ += file_container.__all__
+__all__ += hdf5_utils.__all__
+__all__ += yaml_utils.__all__
 __all__.sort()
